import 'dart:io';

import 'package:flutter/material.dart';

class Photon extends StatelessWidget {
  final String path;
  final dynamic height;
  final dynamic width;
  final List<double>? radius;
  final Widget? child;
  final double elevation;
  final bool isCircle;
  final BorderSide border;
  final List<double> margin;
  final GestureTapCallback? onTap;

  const Photon(
    Key? key,
    this.path, {
    this.height = const [0, double.infinity],
    this.width = const [0, double.infinity],
    this.margin = const [0, 0, 0, 0],
    this.radius,
    this.elevation = 0,
    this.onTap,
    this.isCircle = false,
    this.border = BorderSide.none,
    this.child,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: EdgeInsets.only(top: margin[0], right: margin[1], bottom: margin[2], left: margin[3]),
      child: ConstrainedBox(
        constraints: BoxConstraints(
          minHeight: isOne(height) ? height : height[0],
          maxHeight: isOne(height) ? height : height[1],
          minWidth: isOne(width) ? width : width[0],
          maxWidth: isOne(width) ? width : width[1],
        ),
        child: Material(
          elevation: elevation,
          shape: isCircle == false
              ? RoundedRectangleBorder(
                  borderRadius: radius == null
                      ? BorderRadius.zero
                      : BorderRadius.only(
                          topLeft: Radius.circular(radius![0]),
                          topRight: Radius.circular(radius![1]),
                          bottomRight: Radius.circular(radius![2]),
                          bottomLeft: Radius.circular(radius![3]),
                        ),
                  side: border)
              : CircleBorder(side: border),
          clipBehavior: Clip.hardEdge,
          child: Ink.image(
            image: image(path),
            fit: BoxFit.cover,
            child: InkWell(
              onTap: onTap,
              child: child,
            ),
          ),
        ),
      ),
    );
  }
}


ImageProvider image(String path) {
  if (path.startsWith('assets')) {
    return AssetImage(path);
  } else if (path.startsWith('http') || path.startsWith('https')) {
    return NetworkImage(path);
  } else {
    return FileImage(File(path));
  }
}


bool isOne(dynamic height) {
  try {
    height as double;
    return true;
  } catch (e) {
    return false;
  }
}